import React from 'react';
import { matchPath } from 'react-router';
import invariant from 'tiny-invariant';
import { useNamedRouting } from './NamedRouter';
const NamedSwitch = ({ location: locationFromProps, children }) => {
    const context = useNamedRouting();
    invariant(context, 'You should not use <NamedSwitch> outside a <NamedRouter>');
    const location = locationFromProps || context.location;
    let element = null;
    let match = null;
    React.Children.forEach(children, (child) => {
        if (match === null && React.isValidElement(child)) {
            element = child;
            const path = child.props.name ? context.getRawPath(child.props.name) : child.props.from;
            match = matchPath(location.pathname, Object.assign({}, child.props, { path }));
        }
    });
    return match && element
        ? React.cloneElement(element, { location, computedMatch: match })
        : null;
};
export default NamedSwitch;
